pub struct SqliteBucket { /* private fields */ }Expand description
SQLite storage bucket (collection)
Implementations
Sourceimpl SqliteBucket
impl SqliteBucket
Sourcepub fn existing_columns(&self) -> Vec<String>
pub fn existing_columns(&self) -> Vec<String>
Returns all column names currently in the schema cache
Sourcepub fn has_column(&self, name: &str) -> bool
pub fn has_column(&self, name: &str) -> bool
Check if a column exists in the schema cache